//
// This demo shows how to load data from a csv file and store it into objects.
//
// @author Pierre Dragicevic
//

import java.util.Arrays;
import java.util.Comparator;

void setup() {
  
  // Creates a new table from a csv file that uses ";" as separator
  // and where the second line should be ignored.
  Table table = new Table("Camera.csv", ";", new int[]{2});

  // Converts the table into a list of Camera objects
  int rows = table.getRowCount();
  Camera[] cameras = new Camera[rows];
  for (int i=0; i<rows; i++)
    cameras[i] = new Camera(table, i);
    
  // Sorts the cameras by price (this is Java code)
  Arrays.sort(cameras, new Comparator() { 
    public int compare(Object o1, Object o2) {
      return ((Camera)o1).price - ((Camera)o2).price;
    }
  });
    
  // Prints the 5 cheapest cameras
  println("\nThe cheapest cameras are:");
  for (int i=0; i<min(5,rows); i++)
    println(cameras[i]);
}


